@@ -1,3 +1,5 @@
+# © Copyright Databand.ai, an IBM Company 2022
+
 from airflow.hooks.postgres_hook import PostgresHook
 from airflow.models.baseoperator import BaseOperator
 from airflow.utils.decorators import apply_defaults
@@ -17,6 +19,4 @@ class LogPostgresTableOperator(BaseOperator):
     def execute(self, context):
         hook = PostgresHook(postgres_conn_id=self.conn_id)
         connection_string = hook.get_uri()
-        log_pg_table(
-            self.table_name, connection_string, with_histograms=True,
-        )
+        log_pg_table(self.table_name, connection_string, with_histograms=True)
